@@ -19,6 +19,10 @@
 #  define PLATFORM_IS_ARM
 #endif
 
+#if defined(__powerpc__) || defined(__powerpc64__)
+#  define PLATFORM_IS_POWERPC
+#endif
+
 namespace snmalloc
 {
   /**
@@ -36,6 +40,20 @@ namespace snmalloc
      * This architecture cannot access cpu cycles counters.
      */
     NoCpuCycleCounters = (1 << 1),
+    /**
+     * This architecture enforces strict pointer provenance; we bound the
+     * pointers given out on malloc() and friends and must, therefore retain
+     * internal high-privilege pointers for recycling memory on free().
+     */
+    StrictProvenance = (1 << 2),
+  };
+
+  enum AalName : int
+  {
+    ARM,
+    PowerPC,
+    X86,
+    X86_SGX,
   };
 
   /**
@@ -46,6 +64,31 @@ namespace snmalloc
   template<class Arch>
   struct AAL_Generic : Arch
   {
+    /*
+     * Provide a default specification of address_t as uintptr_t for Arch-es
+     * that support IntegerPointers.  Those Arch-es without IntegerPoihnters
+     * must explicitly give their address_t.
+     *
+     * This somewhat obtuse way of spelling the defaulting is necessary so
+     * that all arguments to std::conditional_t are valid, even if they
+     * wouldn't be valid in context.  One might rather wish to say
+     *
+     *   std::conditional_t<..., uintptr_t, Arch::address_t>
+     *
+     * but that requires that Arch::address_t always be given, precisely
+     * the thing we're trying to avoid with the conditional.
+     */
+
+    struct default_address_t
+    {
+      using address_t = uintptr_t;
+    };
+
+    using address_t = typename std::conditional_t<
+      (Arch::aal_features & IntegerPointers) != 0,
+      default_address_t,
+      Arch>::address_t;
+
     /**
      * Prefetch a specific address.
      *
@@ -102,6 +145,8 @@ namespace snmalloc
 #  include "aal_x86_sgx.h"
 #elif defined(PLATFORM_IS_ARM)
 #  include "aal_arm.h"
+#elif defined(PLATFORM_IS_POWERPC)
+#  include "aal_powerpc.h"
 #endif
 
 namespace snmalloc
