@@ -1,25 +1,37 @@
 #pragma once
 
+#include "ds/address.h"
 #include "pal_plain.h"
 #ifdef OPEN_ENCLAVE
-extern "C" const void* __oe_get_heap_base();
-extern "C" const void* __oe_get_heap_end();
 extern "C" void* oe_memset_s(void* p, size_t p_size, int c, size_t size);
-extern "C" void oe_abort();
+extern "C" [[noreturn]] void oe_abort();
 
 namespace snmalloc
 {
   class PALOpenEnclave
   {
-    std::atomic<void*> oe_base = nullptr;
+    static inline std::atomic<void*> oe_base;
+    static inline void* oe_end = nullptr;
 
   public:
+    /**
+     * This will be called by oe_allocator_init to set up enclave heap bounds.
+     */
+    static void setup_initial_range(void* base, void* end)
+    {
+      oe_base = base;
+      oe_end = end;
+    }
+
     /**
      * Bitmap of PalFeatures flags indicating the optional features that this
      * PAL supports.
      */
     static constexpr uint64_t pal_features = 0;
-    static void error(const char* const str)
+
+    static constexpr size_t page_size = 0x1000;
+
+    [[noreturn]] static void error(const char* const str)
     {
       UNUSED(str);
       oe_abort();
@@ -28,17 +40,9 @@ namespace snmalloc
     template<bool committed>
     void* reserve(size_t size) noexcept
     {
-      if (oe_base == 0)
-      {
-        void* dummy = NULL;
-        // If this CAS fails then another thread has initialised this.
-        oe_base.compare_exchange_strong(
-          dummy, const_cast<void*>(__oe_get_heap_base()));
-      }
-
       void* old_base = oe_base;
       void* next_base;
-      auto end = __oe_get_heap_end();
+      auto end = oe_end;
       do
       {
         auto new_base = old_base;
